@@ -6,7 +6,7 @@ use strict;
 use warnings;
 
 use version;
-our $VERSION = version->new('1.07');
+our $VERSION = version->new('1.08');
 our $AUTHORITY = 'cpan:MAROS';
 
 1;
@@ -27,7 +27,9 @@ CatalystX::I18N - Catalyst internationalisation (I18N) framework
      +CatalystX::I18N::Role::GetLocale
      +CatalystX::I18N::Role::DateTime
      +CatalystX::I18N::Role::Maketext
- /; # Choose only the roles you need
+ /; 
+ # Choose only the roles you need 
+ # CatalystX::I18N::Role::All is a convinient shortcut to load all available roles
  
  # Optionally also load request and response roles
  use CatalystX::RoleApplicator;
@@ -56,8 +58,7 @@ CatalystX::I18N - Catalyst internationalisation (I18N) framework
          }
      },
  );
- 
- 
+
  package MyApp::Catalyst::Controller::Main;
  use strict;
  use warnings;
@@ -108,7 +109,13 @@ Basic I18N role that glues everything toghether.
 
 =item * L<CatalystX::I18N::Role::Maketext> 
 
-Adds a maketext capability to a Catalyst application.
+Localize text via L<Locale::Maketext>. Prefered over 
+L<CatalystX::I18N::Role::DataLocalize>
+
+=item * L<CatalystX::I18N::Role::DataLocalize> 
+
+Localize text via L<Data::Localize>. Alternative to 
+L<CatalystX::I18N::Role::Maketext>
 
 =item * L<CatalystX::I18N::Role::DateTime>
 
@@ -120,7 +127,7 @@ Methods for localizing numbers.
 
 =item * L<CatalystX::I18N::TraitFor::Request>
 
-Extends a L<Catalyst::Request> with usefull methods to help dealing with
+Extends L<Catalyst::Request> with usefull methods to help dealing with
 various I18N related information in HTTP requests.
 
 =item * L<CatalystX::I18N::TraitFor::Response>
@@ -129,15 +136,25 @@ Adds a C<Content-Language> header to the response.
 
 =item * L<CatalystX::I18N::Role::GetLocale> 
 
-Tries best to determine the appropriate locale for the current request.
+Tries to determine the most appropriate locale for the current request.
 
 =item * L<CatalystX::I18N::Model::Maketext>
 
-Provides access to L<Locale::Maketext> classes via Catalyst models.
+Provides access to L<Locale::Maketext> classes via a Catalyst model.
+
+=item * L<CatalystX::I18N::Model::DataLocalize>
+
+Provides access to a L<Data::Localize> class via a Catalyst model.
 
 =item * L<CatalystX::I18N::Maketext>
 
-Wrapper around L<Locale::Maketext>. Can also be used outside of Catalyst.
+Helpful wrapper around L<Locale::Maketext>. Can also be used outside of 
+Catalyst.
+
+=item * L<CatalystX::I18N::DataLocalize>
+
+Helpful wrapper around L<Data::Localize>. Can also be used outside of 
+Catalyst.
 
 =back
 
@@ -167,7 +184,7 @@ Catalyst configuration
  );
 
 The configuration must be stored under the key C<I18N>. It should contain
-a hash of C<locales> and optionally a default locale (C<default_locale>).
+a hashref of C<locales> and optionally a default locale (C<default_locale>).
 
 Locales can be marked as C<inactive>. Inactive locales will not be selected
 by the L<CatalystX::I18N::Role::GetLocale/get_locale> method.
@@ -178,15 +195,15 @@ L<CatalystX::I18N::Model::Maketext> together with L<CatalystX::I18N::Maketext>
 the generated lexicons will also inherit in the given order.
 
 Additional configuration values are defined by the various 
-CatalystX::I18N::Role::Maketext::* plugins.
+CatalystX::I18N::Role::* plugins.
 
 =head1 EXTENDING
 
-Extending the functionality of the CatalystX::I18N distribution is easy.
+Extending the functionality of CatalystX::I18N distribution is easy.
 
 E.g. writing a new plugin that does some processing when the locale changes
 
- package CatalystX::MyI18N::Plugin;
+ package CatalystX::MyI18N::Role::MyPlugin;
  use Moose::Role;
  use namespace::autoclean;
  
@@ -199,7 +216,7 @@ E.g. writing a new plugin that does some processing when the locale changes
 
 =head1 SEE ALSO
 
-L<Locale::Maketext>, <Locale::Maketext::Lexicon>,
+L<Locale::Maketext>, <Locale::Maketext::Lexicon>, L<Data::Localize>, 
 L<Number::Format>, L<DateTime::Locale>, L<DateTime::Format::CLDR>, 
 L<DateTime::TimeZone>, L<HTTP::BrowserDetect> and L<Locale::Geocode>
 
