@@ -5,10 +5,9 @@ package CatalystX::I18N::Role::All;
 use CatalystX::I18N::Meta::Role;
 
 use namespace::autoclean;
-use Moose::Role -metaclass => 'CatalystX::I18N::Meta::Role';
+use Moose::Role;
 requires qw(response_class request_class);
 
-
 with qw(
     CatalystX::I18N::Role::Base
     CatalystX::I18N::Role::DateTime
@@ -18,13 +17,39 @@ with qw(
     CatalystX::I18N::Role::Collate
 );
 
+before 'setup' => sub {
+    my ($class) = @_;
+    
+    for my $type (qw(Response Request)) {
+        my $accessor_method = lc($type).'_class';
+        my $super_class = $class->$accessor_method();
+        
+        # Get role
+        my $role_class = 'CatalystX::I18N::TraitFor::'.$type;
+        Class::MOP::load_class($role_class);
+        
+        # Check if role has already been applied
+        next
+            if grep { $_->meta->does_role($role_class) } $super_class->meta->linearized_isa;
+        
+        # Build anon class with our roles
+        my $meta = Moose::Meta::Class->create_anon_class(
+            superclasses => [$super_class],
+            roles        => [$role_class],
+            cache        => 1,
+        );
+        
+        $class->$accessor_method($meta->name);
+    }
+};
 
 around 'setup_component' => sub {
     my $orig  = shift;
-    my ($self,$component) = @_;
+    my ($class,$component) = @_;
     
     Class::MOP::load_class($component);
     
+    # Load View::TT role
     if ($component->isa('Catalyst::View::TT')
         && $component->can('meta')) {
         my $component_meta = $component->meta;
@@ -35,7 +60,7 @@ around 'setup_component' => sub {
         }
     }
     
-    return $self->$orig($component);
+    return $class->$orig($component);
 };
 
 no Moose::Role;
